/************************************************************************/
/*		aISA-P31B Device Driver for Windows 9x/NT						*/
/*																		*/
/*			aisa31b.h	-	Win32 interface definition					*/
/*			date		-	1999/10/14									*/
/************************************************************************/

#if !defined( AISA31B_H )
#define	AISA31B_H

#ifdef	__cplusplus
extern	"C" {
#endif

/*==================*/
/*	Error Code		*/
/*==================*/
#define	AISA31B_SUCCESS					0	/* Successfully proccessed */
#define	AISA31B_ERR_SYSTEM				1	/* Call GetLastError() */
#define	AISA31B_ERR_NO_DEVICE			2	/* No card */
#define	AISA31B_ERR_IN_USE				3	/* Device is in use */
#define	AISA31B_ERR_INVALID_SLOT		4	/* Invalid slot number */
#define	AISA31B_ERR_RESOURCE			5	/* Resource exhaustion */
#define	AISA31B_ERR_INVALID_PORT		6	/* Invalid port */
#define	AISA31B_ERR_INVALID_ARGUMENT	7	/* Invalid argument */
#define	AISA31B_ERR_NO_CREATE			8	/* No created device */

/*==========================================*/
/*	aISA-P31 card's relative port address	*/
/*==========================================*/
#define	AISA31B_PORT_1	0
#define	AISA31B_PORT_2	1
#define	AISA31B_PORT_3	2
#define	AISA31B_PORT_4	3

/*==================*/
/*	Miscellaneous	*/
/*==================*/
#define	AISA31B_MAX_SLOTS	16			/* Maximum number of slots */
#define AISA31B_MAX_PORTS	4			/* Maximum number of user ports */

										/* default search */
#define	AISA31B_SLOT_AUTO		( ( WORD ) ~0U )

/*==============*/
/*	Device ID	*/
/*==============*/
#define	AISA31B_BOARD_ID	0x9031		/* isa bus device id */
#define	AISA31B_VENDOR_ID	0x136c		/* isa bus vendor id */
										/* our device id */
#define	AISA31B_DEVICE_ID	( ( DWORD )AISA31B_BOARD_ID\
							| ( ( DWORD )AISA31B_VENDOR_ID << 16 ) )

/*==================================*/
/*	Resource infomation structure	*/
/*==================================*/
#define	AISA31B_MAX_MEM		9			/* number of memory windows */
#define	AISA31B_MAX_IO		20			/* number of i/o windows */
#define	AISA31B_MAX_IRQ		7			/* number of irqs */
#define	AISA31B_MAX_DMA		7			/* number of dmas */

typedef	struct	_AISA31BRESOURCE {
	DWORD	dwNumMemWindows;					/* Not used */
	DWORD	dwMemBase		[AISA31B_MAX_MEM];	/* Not used */
	DWORD	dwMemLength		[AISA31B_MAX_MEM];	/* Not used */
	DWORD	dwMemAttrib		[AISA31B_MAX_MEM];	/* Not used */
	DWORD	dwNumIOPorts;						/* Num IO ports */
	DWORD	dwIOPortBase	[AISA31B_MAX_IO];	/* I/O port base */
	DWORD	dwIOPortLength	[AISA31B_MAX_IO];	/* I/O port length */
	DWORD	dwNumIRQs;							/* Not used */
	DWORD	dwIRQRegisters	[AISA31B_MAX_IRQ];	/* Not used */
	DWORD	dwIRQAttrib		[AISA31B_MAX_IRQ];	/* Not used */
	DWORD	dwNumDMAs;							/* Not used */
	DWORD	dwDMALst		[AISA31B_MAX_DMA];	/* Not used */
	DWORD	dwDMAAttrib		[AISA31B_MAX_DMA];	/* Not used */
	DWORD	dwReserved1		[3];				/* Not used */
} AISA31BRESOURCE, *PAISA31BR;

#if !defined( AISA31B_DRIVER )
#define	AISA31B_API

#if !defined( AISA31B_DLL )
	#define AISA31BLIB_API	extern __declspec( dllimport )
#else
	#define AISA31BLIB_API	extern __declspec( dllexport )
#endif

#ifdef _BORLANDC_
	#define EXPVAR			__pascal
#else
	#define	EXPVAR
#endif

/*==================*/
/*	API Functions	*/
/*==================*/

AISA31BLIB_API BOOL	WINAPI	Aisa31bGetVersion( PDWORD pdwDllVersion, PDWORD pdwDriverVersion );
AISA31BLIB_API BOOL	WINAPI	Aisa31bCreate( PWORD pwLogSlot );
AISA31BLIB_API BOOL	WINAPI	Aisa31bClose( WORD wLogSlot );
AISA31BLIB_API BOOL	WINAPI	Aisa31bGetResource( WORD wLogSlot, PAISA31BR pres );
AISA31BLIB_API BOOL	WINAPI	Aisa31bInPort( WORD wLogSlot, DWORD dwLogPort, PBYTE pbInValue );
AISA31BLIB_API BOOL	WINAPI	Aisa31bOutPort( WORD wLogSlot, DWORD dwLogPort, BYTE bOutValue );
AISA31BLIB_API DWORD	WINAPI	Aisa31bGetLastError( WORD wLogSlot );

#endif	/* #if !defined( AISA31B_DRIVER ) */

#ifdef	__cplusplus
}
#endif

#endif	/* #if !defined( AISA31B_H ) */

/**/